import subprocess
import sys

install_command = [sys.executable, "-m", "pip", "install", "chatgptmax"]
subprocess.check_call(install_command)

from chatgptmax import clean_stopwords

def test_pypi_installation():
    text = "This is a test to remove stopwords from the text."
    cleaned_text = clean_stopwords(text)
    assert cleaned_text == "This test remove stopwords from text."

if __name__ == "__main__":
    test_pypi_installation()



import sys
sys.path.append("./")
import pytest
from chatgptmax import clean, clean_stopwords, read_data, clean_text_from_file, send

# Test for the clean function
def test_clean():
    text = "Check out this link: http://example.com and email me at test@example.com!"
    cleaned_text = clean(text)
    assert cleaned_text == "Checkoutthislinkandemailmeat"


# Test for the clean_stopwords function
def test_clean_stopwords():
    text = "This is a test to remove stopwords from the text."
    cleaned_text = clean_stopwords(text)
    assert cleaned_text == "This test remove stopwords from text."


# Test for the read_data function
def test_read_data(tmp_path):
    file = tmp_path / "test.txt"
    file.write_text("This is a test file.")
    assert read_data(file) == "This is a test file."


# Test for the clean_text_from_file function
def test_clean_text_from_file(tmp_path):
    file = tmp_path / "test.txt"
    file.write_text("This is a test to remove stopwords from the file.")
    cleaned_text = clean_text_from_file(file)
    assert cleaned_text == "This test remove stopwords from file."


# Test for the send function
def test_send():
    prompt = "Summarize the following text for me:"
    text_data = "This is a test text to be summarized by ChatGPT."
    response = send(prompt, text_data)
    assert isinstance(response, list)
    assert len(response) > 0


# Test for the send function with missing prompt
def test_send_missing_prompt():
    response = send()
    assert response == "Error: Prompt is missing. Please provide a prompt."


# Test for the send function with missing data
def test_send_missing_data():
    prompt = "Summarize the following text for me:"
    response = send(prompt)
    assert response == "Error: Text data is missing. Please provide some text data."



from setuptools import setup, find_packages

# read the contents of your README file
from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name="chatgptmax",
    version="1.0.3",
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=find_packages(),
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    install_requires=[
        "openai",
        "tiktoken"
    ],
    author="Victoria Drake",
    author_email="hello@victoria.dev",
    description="Take large input or read a file and send it in chunks to ChatGPT.",
    license="MIT",
    keywords="chatgpt openai",
    url="https://github.com/victoriadrake/chatgptmax/",
)
